Rename following members of struct rt_dot11d_info to avoid checkpatch
warning: Avoid CamelCase

        bEnabled -> enabled
        CountryIelen -> country_len
        CountryIeBuf -> country_buffer
        CountryIeSrcAddr -> country_src_addr
        CountryIeWatchdog -> country_watchdog
        MaxTxPwrDbmList -> mac_tx_power_list
        State -> state

Signed-off-by: Himadri Pandya <himadri18...@gmail.com>
---
 drivers/staging/rtl8192e/dot11d.c | 28 ++++++++++++++--------------
 drivers/staging/rtl8192e/dot11d.h | 30 +++++++++++++++---------------
 2 files changed, 29 insertions(+), 29 deletions(-)

diff --git a/drivers/staging/rtl8192e/dot11d.c 
b/drivers/staging/rtl8192e/dot11d.c
index 711e8264183e..7e489f0f3c41 100644
--- a/drivers/staging/rtl8192e/dot11d.c
+++ b/drivers/staging/rtl8192e/dot11d.c
@@ -46,12 +46,12 @@ void dot11d_init(struct rtllib_device *ieee)
 {
        struct rt_dot11d_info *pDot11dInfo = GET_DOT11D_INFO(ieee);
 
-       pDot11dInfo->bEnabled = false;
+       pDot11dInfo->enabled = false;
 
-       pDot11dInfo->State = DOT11D_STATE_NONE;
-       pDot11dInfo->CountryIeLen = 0;
+       pDot11dInfo->state = DOT11D_STATE_NONE;
+       pDot11dInfo->country_len = 0;
        memset(pDot11dInfo->channel_map, 0, MAX_CHANNEL_NUMBER + 1);
-       memset(pDot11dInfo->MaxTxPwrDbmList, 0xFF, MAX_CHANNEL_NUMBER + 1);
+       memset(pDot11dInfo->max_tx_power_list, 0xFF, MAX_CHANNEL_NUMBER + 1);
        RESET_CIE_WATCHDOG(ieee);
 }
 EXPORT_SYMBOL(dot11d_init);
@@ -104,13 +104,13 @@ void Dot11d_Reset(struct rtllib_device *ieee)
        u32 i;
 
        memset(pDot11dInfo->channel_map, 0, MAX_CHANNEL_NUMBER + 1);
-       memset(pDot11dInfo->MaxTxPwrDbmList, 0xFF, MAX_CHANNEL_NUMBER + 1);
+       memset(pDot11dInfo->max_tx_power_list, 0xFF, MAX_CHANNEL_NUMBER + 1);
        for (i = 1; i <= 11; i++)
                (pDot11dInfo->channel_map)[i] = 1;
        for (i = 12; i <= 14; i++)
                (pDot11dInfo->channel_map)[i] = 2;
-       pDot11dInfo->State = DOT11D_STATE_NONE;
-       pDot11dInfo->CountryIeLen = 0;
+       pDot11dInfo->state = DOT11D_STATE_NONE;
+       pDot11dInfo->country_len = 0;
        RESET_CIE_WATCHDOG(ieee);
 }
 
@@ -122,7 +122,7 @@ void Dot11d_UpdateCountryIe(struct rtllib_device *dev, u8 
*pTaddr,
        struct chnl_txpow_triple *pTriple;
 
        memset(pDot11dInfo->channel_map, 0, MAX_CHANNEL_NUMBER + 1);
-       memset(pDot11dInfo->MaxTxPwrDbmList, 0xFF, MAX_CHANNEL_NUMBER + 1);
+       memset(pDot11dInfo->max_tx_power_list, 0xFF, MAX_CHANNEL_NUMBER + 1);
        MaxChnlNum = 0;
        NumTriples = (CoutryIeLen - 3) / 3;
        pTriple = (struct chnl_txpow_triple *)(pCoutryIe + 3);
@@ -143,7 +143,7 @@ void Dot11d_UpdateCountryIe(struct rtllib_device *dev, u8 
*pTaddr,
 
                for (j = 0; j < pTriple->num_chnls; j++) {
                        pDot11dInfo->channel_map[pTriple->first_chnl + j] = 1;
-                       pDot11dInfo->MaxTxPwrDbmList[pTriple->first_chnl + j] =
+                       pDot11dInfo->max_tx_power_list[pTriple->first_chnl + j] 
=
                                                 pTriple->max_tx_power;
                        MaxChnlNum = pTriple->first_chnl + j;
                }
@@ -153,18 +153,18 @@ void Dot11d_UpdateCountryIe(struct rtllib_device *dev, u8 
*pTaddr,
 
        UPDATE_CIE_SRC(dev, pTaddr);
 
-       pDot11dInfo->CountryIeLen = CoutryIeLen;
-       memcpy(pDot11dInfo->CountryIeBuf, pCoutryIe, CoutryIeLen);
-       pDot11dInfo->State = DOT11D_STATE_LEARNED;
+       pDot11dInfo->country_len = CoutryIeLen;
+       memcpy(pDot11dInfo->country_buffer, pCoutryIe, CoutryIeLen);
+       pDot11dInfo->state = DOT11D_STATE_LEARNED;
 }
 
 void DOT11D_ScanComplete(struct rtllib_device *dev)
 {
        struct rt_dot11d_info *pDot11dInfo = GET_DOT11D_INFO(dev);
 
-       switch (pDot11dInfo->State) {
+       switch (pDot11dInfo->state) {
        case DOT11D_STATE_LEARNED:
-               pDot11dInfo->State = DOT11D_STATE_DONE;
+               pDot11dInfo->state = DOT11D_STATE_DONE;
                break;
        case DOT11D_STATE_DONE:
                Dot11d_Reset(dev);
diff --git a/drivers/staging/rtl8192e/dot11d.h 
b/drivers/staging/rtl8192e/dot11d.h
index 921e83e3dd47..9e5aca6ad9de 100644
--- a/drivers/staging/rtl8192e/dot11d.h
+++ b/drivers/staging/rtl8192e/dot11d.h
@@ -30,27 +30,27 @@ enum dot11d_state {
 };
 
 /**
  * struct rt_dot11d_info * @CountryIeLen: value greater than 0 if
  *               @CountryIeBuf contains valid country information element.
  * @channel_map: holds channel values
  *             0 - invalid,
  *             1 - valid (active scan),
  *             2 - valid (passive scan)
  * @CountryIeSrcAddr - Source AP of the country IE
  */
 
 struct rt_dot11d_info {
-       bool bEnabled;
+       bool enabled;
 
-       u16 CountryIeLen;
-       u8  CountryIeBuf[MAX_IE_LEN];
-       u8  CountryIeSrcAddr[6];
-       u8  CountryIeWatchdog;
+       u16 country_len;
+       u8  country_buffer[MAX_IE_LEN];
+       u8  country_src_addr[6];
+       u8  country_watchdog;
 
        u8  channel_map[MAX_CHANNEL_NUMBER + 1];
-       u8  MaxTxPwrDbmList[MAX_CHANNEL_NUMBER + 1];
+       u8  max_tx_power_list[MAX_CHANNEL_NUMBER + 1];
 
-       enum dot11d_state State;
+       enum dot11d_state state;
 };
 
 static inline void cpMacAddr(unsigned char *des, unsigned char *src)
@@ -62,18 +62,18 @@ static inline void cpMacAddr(unsigned char *des, unsigned 
char *src)
         ((struct rt_dot11d_info *)((__pIeeeDev)->pDot11dInfo))
 
 #define IS_DOT11D_ENABLE(__pIeeeDev)                   \
-        (GET_DOT11D_INFO(__pIeeeDev)->bEnabled)
+        (GET_DOT11D_INFO(__pIeeeDev)->enabled)
 #define IS_COUNTRY_IE_VALID(__pIeeeDev)                        \
-       (GET_DOT11D_INFO(__pIeeeDev)->CountryIeLen > 0)
+       (GET_DOT11D_INFO(__pIeeeDev)->country_len > 0)
 
 #define IS_EQUAL_CIE_SRC(__pIeeeDev, __pTa)            \
         ether_addr_equal_unaligned( \
-               GET_DOT11D_INFO(__pIeeeDev)->CountryIeSrcAddr, __pTa)
+               GET_DOT11D_INFO(__pIeeeDev)->country_src_addr, __pTa)
 #define UPDATE_CIE_SRC(__pIeeeDev, __pTa)              \
-       cpMacAddr(GET_DOT11D_INFO(__pIeeeDev)->CountryIeSrcAddr, __pTa)
+       cpMacAddr(GET_DOT11D_INFO(__pIeeeDev)->country_src_addr, __pTa)
 
 #define GET_CIE_WATCHDOG(__pIeeeDev)                           \
-        (GET_DOT11D_INFO(__pIeeeDev)->CountryIeWatchdog)
+        (GET_DOT11D_INFO(__pIeeeDev)->country_watchdog)
 static inline void RESET_CIE_WATCHDOG(struct rtllib_device *__pIeeeDev)
 {
        GET_CIE_WATCHDOG(__pIeeeDev) = 0;
@@ -30,27 +30,27 @@ enum dot11d_state {
 
 /**
- * struct rt_dot11d_info * @CountryIeLen: value greater than 0 if
- *               @CountryIeBuf contains valid country information element.
+ * struct rt_dot11d_info * @country_len: value greater than 0 if
+ *               @country_buffer contains valid country information element.
  * @channel_map: holds channel values
  *             0 - invalid,
@@ -30,27 +30,27 @@ enum dot11d_state {
  *             1 - valid (active scan),
  *             2 - valid (passive scan)
- * @CountryIeSrcAddr - Source AP of the country IE
+ * @country_src_addr - Source AP of the country IE
  */
 
-- 
2.17.1

_______________________________________________
devel mailing list
de...@linuxdriverproject.org
http://driverdev.linuxdriverproject.org/mailman/listinfo/driverdev-devel

Reply via email to